==> wiki3_4_1.zip: wiki3_4_1/plugin/bbs/BBS2Handler.pm <==
############################################################
#
# fŃvOC̃ANVnhB
#
############################################################
package plugin::bbs::BBS2Handler;
use strict;
#===========================================================
# RXgN^
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# L̏
#===========================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $bbsname = $cgi->param("bbsname");
	my $name    = $cgi->param("name");
	my $subject = $cgi->param("subject");
	my $message = $cgi->param("message");
	
	if($name    eq ""){ $name    = ""; }
	if($subject eq ""){ $subject = ""; }
	
	
	if($bbsname eq ""){
		return $wiki->error("p[^słB");
	}
	if($message eq ""){
		return $wiki->error("{͂ĂB");
	}
	my $pagename = $self->get_page_name($wiki,$bbsname);
	my $content = "!![[$subject|$pagename]] - $name (".&Util::format_date(time()).")\n".
	              "$message\n";
	
	if($cgi->param("no_comment") ne "true"){
		$content .= "{{comment}}\n";
	}
	$wiki->save_page($pagename,$content);
	
	return $wiki->call_handler("");
}

#===========================================================
# 쐬y[W擾
#===========================================================
sub get_page_name {
	my $self = shift;
	my $wiki = shift;
	my $name = shift;
	my $count = 0;
	foreach my $pagename ($wiki->get_page_list()){
		if($pagename =~ /^BBS-$name\/([0-9]+)$/){
			if($count < $1){
				$count = $1;
			}
		}
	}
	$count++;
	return "BBS-$name/$count";
}

1;

==> wiki3_5_0.zip: wiki3_5_0/plugin/bbs/BBS2Handler.pm <==
############################################################
#
# Ǽǥץ饰Υϥɥ顣
#
############################################################
package plugin::bbs::BBS2Handler;
#use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# ν񤭹
#===========================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $bbsname = $cgi->param("bbsname");
	my $name    = $cgi->param("name");
	my $subject = $cgi->param("subject");
	my $message = $cgi->param("message");
	my $page    = $cgi->param("page");
	my $option  = $cgi->param("option");
	
	if($name    eq ""){
		$name    = "̵̾";
	} else {
		# post_nameȤǥå򥻥åȤ
		my $cookie = $cgi->cookie(-name=>'post_name',-value=>$name,-expires=>'+1M');
		print "Set-Cookie: ",$cookie->as_string,"\n";
	}
	
	if($subject eq ""){
		$subject = "̵";
	}
	
	if($bbsname eq ""){
		return $wiki->error("ѥ᡼Ǥ");
	}
	if($message eq ""){
		return $wiki->error("ʸϤƤ");
	}
	my $pagename = $self->get_page_name($wiki,$bbsname);
	my $content = "!![[$subject|$pagename]] - $name (".&Util::format_date(time()).")\n".
	              "$message\n";
	
	# no_commentץ
	if($option eq "no_comment"){
		
	# reverse_commentץ
	} elsif($option eq "reverse_comment"){
		$content .= "{{comment reverse}}\n";
	# ǥե
	} else {
		$content .= "{{comment}}\n";
	}
	$wiki->save_page($pagename,$content);
	
	# Υڡ˥쥯
	$wiki->redirect($pagename);
}

#===========================================================
# ڡ̾
#===========================================================
sub get_page_name {
	my $self = shift;
	my $wiki = shift;
	my $name = shift;
	my $count = 0;
	foreach my $pagename ($wiki->get_page_list()){
		if($pagename =~ /^BBS-$name\/([0-9]+)$/){
			if($count < $1){
				$count = $1;
			}
		}
	}
	$count++;
	return "BBS-$name/$count";
}

1;
